SELECT name, external_id, product_count FROM feeds ORDER BY product_count DESC;
SELECT COUNT(*) as total_products FROM products;
SELECT COUNT(*) as total_offers FROM product_offers;
SELECT COUNT(*) as with_model FROM products WHERE model IS NOT NULL;
SELECT brand, model, COUNT(*) c FROM products WHERE model IS NOT NULL GROUP BY brand, model ORDER BY c DESC LIMIT 10;
