SELECT column_name FROM information_schema.columns WHERE table_name='feeds' AND column_name='feed_url';
SELECT column_name FROM information_schema.columns WHERE table_name='products' AND column_name='needs_cutout';
