SELECT f.name,
       COUNT(DISTINCT po.product_id) as products,
       COUNT(po.id) as offers
FROM feeds f
LEFT JOIN product_offers po ON po.feed_id = f.id
GROUP BY f.id, f.name
ORDER BY offers DESC;
