-- Check a sample of image URLs per feed to see if they're already cutout/transparent
SELECT f.name as feed, po.image_url 
FROM product_offers po 
JOIN feeds f ON po.feed_id = f.id 
WHERE po.image_url IS NOT NULL AND po.image_url != ''
GROUP BY f.name, po.image_url
ORDER BY f.name
LIMIT 15;
