import React from 'react';
import { AuthProvider, AuthGuard } from './AdminAuth';
import AdminLayout from './AdminLayout';

function EmailContent() {
  return (
    <AdminLayout title="Email">
      <div className="bg-[#141414] border border-[#333] rounded-xl p-12 text-center">
        <div className="text-4xl mb-4">📧</div>
        <div className="text-[#999] text-lg mb-2">Email Campaigns</div>
        <div className="text-[#666] text-sm">Hier komen email templates en campaign management.<br/>Binnenkort beschikbaar.</div>
      </div>
    </AdminLayout>
  );
}

export default function EmailPlaceholder() {
  return <AuthProvider><AuthGuard><EmailContent /></AuthGuard></AuthProvider>;
}
