-- Van Arendonk duplicate example
SELECT p.name, p.brand, po.price, po.external_id 
FROM product_offers po 
JOIN products p ON p.id = po.product_id 
JOIN feeds f ON f.id = po.feed_id 
WHERE f.name LIKE '%Van Arendonk%' 
AND p.brand = 'Nike'
LIMIT 20;
