SELECT po.product_id, f.name as shop, COUNT(*) as cnt, p.name, p.brand
FROM product_offers po
JOIN feeds f ON f.id = po.feed_id
JOIN products p ON p.id = po.product_id
WHERE p.brand IN ('Nike', 'adidas', 'New Balance', 'Puma')
GROUP BY po.product_id, f.name, p.name, p.brand
HAVING COUNT(*) > 1
ORDER BY cnt DESC LIMIT 15;
