SELECT po.external_id, po.price, LEFT(po.sizes::text, 100) as sizes_preview, p.colorway
FROM product_offers po JOIN products p ON p.id = po.product_id
WHERE po.product_id = 1204765 AND po.feed_id = (SELECT id FROM feeds WHERE name = 'Foot Locker NL' LIMIT 1)
LIMIT 5;
