#!/usr/bin/env python3
"""Check feed 20068 details and Van Arendonk 17108 details."""
import requests
import json

WEBGAINS_API = "https://platform-api.webgains.com"
PUBLISHER_ID = "1347930"
TOKEN = "eyJ0eXAiOiJKV1QiLCJhbGciOiJSUzI1NiJ9.eyJhdWQiOiIxMDAwMzEiLCJqdGkiOiIwNjM5ODEwYzQ0YzM1MTBlZmZiMGRkYWNiM2EyNWFlNTg2YzFmNmQ5ODNjNGQ2MDA4NzkwZmM0NTkzY2EyNjg4ZGViZDE4NTgwOThmYjJjYiIsImlhdCI6MTc3MTUxNjc4OS44MzAxMzUsIm5iZiI6MTc3MTUxNjc4OS44MzAxMzcsImV4cCI6MjA4NzA0OTU4OS44MjcwODgsInN1YiI6IjIwMTcwOCIsInNjb3BlcyI6W119.ZxlCDsyBI7_SNUWjO-PUxDYKvQVfuUBzU5n-SgqHdAZCnOj9253yVcJIS5NRXJLrnyx0E_9bn8ymfXS71cvPISA4hPAlKCSMjdkv9f2k2FFwdAlQQ6mdhBB2m9dzHUIn34QwA8s4-ikB1ATKIZeqiJL-3Gh9eiMYPpvaJdCCjN-oGPMhhlehkgA04cZSgwy6HfKgb6uPvUSG9w_tvN8U06uEHKV11DedQHNWWGzuXpd2FEL3baV0z9KjSNMZsJZHx2yHUb6gVWJwaR7_louahMvrPXG-YLgnGvNMcPDPjm-z5HJ-JKcPv9_FBqAYGItZxgeGgVoS8MVhW6lc1a-6CvYtVanfXF42MPPNP-Qq76qRtHPLRBdkIATMuBxVJrMzlprT3n4F0sUUltGR4ixZuzMUm5LeyPMHgmjy2UfYzsl9eVqx0oJCmKUyY9maBXwFLJa8J1NHM_nWp3hPpCGkMyhzHK1DIf_z8Wirg1hp5vKts93eERWJBlQwhucUUS_KnZeC_gVaQ7kT4jCwaEWkpPxPxyXWRoK0mcYS_JGz3JbpVhRLj5DVYIB9k54DXqjYlCx8ezJZE9sf2SX3VWvPvD1xSQD1caTCm0To0B-MkeU1YpEfWdUslpCJXrpOy2Wbs8iDHR1BzNrMnOEr4zbz_EoB4JJe3tGTGjzNLNIw6XI"
HEADERS = {"Authorization": f"Bearer {TOKEN}", "Accept": "application/json"}

# Check feed 20068 - print full product details to understand the merchant
print("=== Feed 20068 (Standaard feed) - Full product details ===")
url = f"{WEBGAINS_API}/auth/publishers/{PUBLISHER_ID}/campaigns/1622250/feeds/products"
params = {"feedIds[]": [20068], "size": 10}
r = requests.get(url, headers=HEADERS, params=params, timeout=30)
data = r.json()
products = data.get("data", [])
for p in products[:3]:
    print(json.dumps(p, indent=2, default=str)[:800])
    print("---")

# Check the feed metadata
print("\n=== Feed 20068 metadata ===")
url2 = f"{WEBGAINS_API}/auth/publishers/{PUBLISHER_ID}/campaigns/1622250/feeds"
r2 = requests.get(url2, headers=HEADERS, timeout=15)
feeds = r2.json()
if isinstance(feeds, dict):
    feeds = feeds.get('data', feeds.get('feeds', []))
for f in feeds:
    if f.get('id') == 20068:
        print(json.dumps(f, indent=2, default=str))

# Check links to identify the shop
print("\n=== Links from feed 20068 products ===")
for p in products[:5]:
    link = p.get('link', '?')
    print(f"  {link[:120]}")
