SELECT f.id, f.name, f.merchant_name, f.product_count, p.slug as network FROM feeds f JOIN providers p ON f.provider_id = p.id ORDER BY f.id;
SELECT COUNT(*) as total_products FROM products;
SELECT COUNT(*) as total_offers FROM product_offers;
