const {Pool} = require('pg');
const p = new Pool({connectionString: 'postgresql://sneakerpicks:SP.r4nD0m-sEcuRe99@172.18.0.5:5432/sneakerpicks'});
p.query('SELECT count(*) FROM products').then(r => {console.log('OK', r.rows); p.end()}).catch(e => {console.log('ERR', e.message); p.end()});
