SELECT reason, COUNT(*) c FROM import_rejects GROUP BY reason ORDER BY c DESC LIMIT 20;
SELECT name, brand, category, reason FROM import_rejects WHERE brand IN ('Nike', 'Adidas', 'adidas', 'New Balance', 'Puma', 'ASICS', 'Asics') LIMIT 10;
