SELECT 'products' as tbl, count(*) FROM products;
SELECT 'offers' as tbl, count(*) FROM product_offers;
SELECT 'feeds' as tbl, count(*) FROM feeds;
SELECT f.name, count(po.id) as offers FROM feeds f LEFT JOIN product_offers po ON po.feed_id = f.id GROUP BY f.name;
SELECT brand, count(*) as cnt FROM products GROUP BY brand ORDER BY cnt DESC LIMIT 20;
SELECT name FROM products WHERE lower(name) LIKE '%hoodie%' OR lower(name) LIKE '%t-shirt%' OR lower(name) LIKE '%pants%' OR lower(name) LIKE '%shorts%' OR lower(name) LIKE '%jacket%' LIMIT 10;
