-- Check gender distribution for Van Arendonk
SELECT gender, count(*) FROM products p
JOIN product_offers po ON po.product_id = p.id
JOIN feeds f ON po.feed_id = f.id
WHERE f.name = 'Van Arendonk NL new'
GROUP BY gender ORDER BY count(*) DESC;

-- Check if there's category info in the feed itself
SELECT * FROM feeds WHERE name = 'Van Arendonk NL new';
