SELECT f.id as feed_id, f.name as feed_name, f.merchant_name, COUNT(po.id) as offers
FROM feeds f
LEFT JOIN product_offers po ON po.feed_id = f.id
GROUP BY f.id, f.name, f.merchant_name
ORDER BY offers DESC;
